# SPDX-FileCopyrightText: Emery Hemingway
#
# SPDX-License-Identifier: LicenseRef-Hippocratic-1.1

let
  pkgOverlay = self: super:
    # Overlay of locally defined packages
    with self; {
      dhall = callPackage ./dhall { };
      genode = callPackage ./upstream { };
      nova = callPackage ./NOVA { };
    };

  toolchainOverlay = import ./toolchain-overlay;
  # Overlay of toolchain patches

  nixpkgs' = builtins.fetchGit {
    # A branch of Nixpkgs with a custom "crossSystem" mechanism
    url = "https://github.com/ehmry/nixpkgs.git";
    ref = "hybrid";
    rev = "e4d734ace275cae70a776771d034c051956c9cab";
  };

in { nixpkgs ? nixpkgs' }:

import nixpkgs {
  # Evaluate an overlayed Nixpkgs for a Genode target
  config.allowUnsupportedSystem = true;
  crossSystem = {
    isx86_64 = true;
    isGenode = true;
    imports = [ ./platform.nix ];
  };
  overlays = [ toolchainOverlay pkgOverlay ];
}
